********************
The sherpa.ui module
********************

.. currentmodule:: sherpa.ui

.. automodule:: sherpa.ui

The :py:mod:`sherpa.ui` module provides an interface to the
:py:class:`sherpa.ui.utils.Session`
object, where a singleton class is used to provide the access but
hidden away. This needs better explanation...

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      add_model
      add_user_pars
      calc_chisqr
      calc_stat
      calc_stat_info
      clean
      conf
      confidence
      contour
      contour_data
      contour_fit
      contour_fit_resid
      contour_kernel
      contour_model
      contour_psf
      contour_ratio
      contour_resid
      contour_source
      copy_data
      covar
      covariance
      create_model_component
      dataspace1d
      dataspace2d
      delete_data
      delete_model
      delete_model_component
      delete_psf
      fake
      fit
      freeze
      get_cdf_plot
      get_chisqr_plot
      get_conf
      get_conf_opt
      get_conf_results
      get_confidence_results
      get_contour_prefs
      get_covar
      get_covar_opt
      get_covar_results
      get_covariance_results
      get_data
      get_data_contour
      get_data_contour_prefs
      get_data_image
      get_data_plot
      get_data_plot_prefs
      get_default_id
      get_delchi_plot
      get_dep
      get_dims
      get_draws
      get_error
      get_filter
      get_fit_contour
      get_fit_plot
      get_fit_results
      get_functions
      get_indep
      get_int_proj
      get_int_unc
      get_iter_method_name
      get_iter_method_opt
      get_kernel_contour
      get_kernel_image
      get_kernel_plot
      get_method
      get_method_name
      get_method_opt
      get_model
      get_model_autoassign_func
      get_model_component
      get_model_component_image
      get_model_component_plot
      get_model_components_plot
      get_model_contour
      get_model_contour_prefs
      get_model_image
      get_model_pars
      get_model_plot
      get_model_plot_prefs
      get_model_type
      get_num_par
      get_num_par_frozen
      get_num_par_thawed
      get_par
      get_pdf_plot
      get_plot_prefs
      get_prior
      get_proj
      get_proj_opt
      get_proj_results
      get_projection_results
      get_psf
      get_psf_contour
      get_psf_image
      get_psf_plot
      get_pvalue_plot
      get_pvalue_results
      get_ratio_contour
      get_ratio_image
      get_ratio_plot
      get_reg_proj
      get_reg_unc
      get_resid_contour
      get_resid_image
      get_resid_plot
      get_rng
      get_sampler
      get_sampler_name
      get_sampler_opt
      get_scatter_plot
      get_source
      get_source_component_image
      get_source_component_plot
      get_source_components_plot
      get_source_contour
      get_source_image
      get_source_plot
      get_split_plot
      get_stat
      get_stat_info
      get_stat_name
      get_staterror
      get_syserror
      get_trace_plot
      guess
      ignore
      ignore_id
      image_close
      image_data
      image_deleteframes
      image_fit
      image_getregion
      image_kernel
      image_model
      image_model_component
      image_open
      image_psf
      image_ratio
      image_resid
      image_setregion
      image_source
      image_source_component
      image_xpaget
      image_xpaset
      int_proj
      int_unc
      link
      list_data_ids
      list_functions
      list_iter_methods
      list_methods
      list_model_components
      list_model_ids
      list_models
      list_priors
      list_psf_ids
      list_samplers
      list_stats
      load_arrays
      load_conv
      load_data
      load_filter
      load_psf
      load_staterror
      load_syserror
      load_table_model
      load_template_interpolator
      load_template_model
      load_user_model
      load_user_stat
      normal_sample
      notice
      notice_id
      paramprompt
      plot
      plot_cdf
      plot_chisqr
      plot_data
      plot_delchi
      plot_fit
      plot_fit_delchi
      plot_fit_ratio
      plot_fit_resid
      plot_kernel
      plot_model
      plot_model_component
      plot_model_components
      plot_pdf
      plot_psf
      plot_pvalue
      plot_ratio
      plot_resid
      plot_scatter
      plot_source
      plot_source_component
      plot_source_components
      plot_trace
      proj
      projection
      reg_proj
      reg_unc
      reset
      restore
      save
      save_arrays
      save_data
      save_delchi
      save_error
      save_filter
      save_model
      save_resid
      save_source
      save_staterror
      save_syserror
      set_conf_opt
      set_covar_opt
      set_data
      set_default_id
      set_dep
      set_filter
      set_full_model
      set_iter_method
      set_iter_method_opt
      set_method
      set_method_opt
      set_model
      set_model_autoassign_func
      set_par
      set_plot_backend
      set_prior
      set_proj_opt
      set_psf
      set_rng
      set_sampler
      set_sampler_opt
      set_source
      set_stat
      set_staterror
      set_syserror
      set_xlinear
      set_xlog
      set_ylinear
      set_ylog
      show_all
      show_conf
      show_covar
      show_data
      show_filter
      show_fit
      show_kernel
      show_method
      show_model
      show_proj
      show_psf
      show_source
      show_stat
      simulfit
      t_sample
      thaw
      uniform_sample
      unlink
      unpack_arrays
      unpack_data
